@@ -640,13 +640,16 @@ class Bitpin:
 
         return self._process_response(f_name, response, f_args)
 
-    def recent_trades(self, market_id: t.Optional[int] = None) -> t.Dict:
+    def recent_trades(self, market_id: t.Optional[int] = None, page: int = None) -> t.Dict:
         """
         Get recent trades.
 
         :param market_id: Market ID (optional)
         :type market_id: int
 
+        :param page: Page number (optional)
+        :type page: int
+
         :return: Recent trades
         :rtype: dict
         """
@@ -656,6 +659,9 @@ class Bitpin:
 
         url = '/v1/odr/matches/'
 
+        if page is not None:
+            url += f'?page={page}'
+
         response = self._request(
             f_name,
             'GET',
@@ -704,13 +710,16 @@ class Bitpin:
             
         return processed_response
 
-    def open_orders(self, market_id: t.Optional[int] = None) -> t.Dict:
+    def open_orders(self, market_id: t.Optional[int] = None, page: int = None) -> t.Dict:
         """
         Get open orders.
 
         :param market_id: Market ID (optional)
         :type market_id: int
 
+        :param page: Page number (optional)
+        :type page: int
+
         :return: Open orders
         :rtype: dict
         """
@@ -720,6 +729,9 @@ class Bitpin:
 
         url = '/v1/odr/orders/?state=active,initial'
 
+        if page is not None:
+            url += f'?page={page}'
+
         response = self._request(
             f_name,
             'GET',
@@ -735,5 +747,3 @@ class Bitpin:
             processed_response['results'] = filtered_results
             
         return processed_response
-
-
